=====================
 Invenio-DB v1.0.0b6
=====================

Invenio-DB v1.0.0b6 was released on May 24, 2017.

About
-----

Database management for Invenio.

What's new
----------

- Initial public release.
- Versioning support using SQLAlchemy-Continuum.
- Upgrades using Alembic.
- Utils for migrating encrypted fields when the secret key changes.

Installation
------------

   $ pip install invenio-db==1.0.0b6

Documentation
-------------

   https://invenio-db.readthedocs.io/

Happy hacking and thanks for flying Invenio-DB.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: https://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-db
|   URL: http://inveniosoftware.org
